@@ -5,17 +5,13 @@ use warnings;
 use Tenjin::Util;
 use Carp;
 
-our $VERSION = "0.070001";
+our $VERSION = "1.000000";
 $VERSION = eval $VERSION;
 
 =head1 NAME
 
 Tenjin::Context - In charge of managing variables passed to Tenjin templates.
 
-=head1 VERSION
-
-version 0.070001
-
 =head1 SYNOPSIS
 
 	# this module is used internally, but if you insist, it is
@@ -83,7 +79,7 @@ sub evaluate {
 	my ($self, $script, $name) = @_;
 
 	my $_context = $self;
-	$script = ($script =~ /\A.*\Z/s) && $& if $Tenjin::BYPASS_TAINT;
+	$script = ($script =~ /\A(.*)\Z/s) && $1 if $Tenjin::BYPASS_TAINT;
 	my $s = $name ? "# line 1 \"$name\"\n" : '';  # line directive
 	$s .= $script;
 
@@ -112,7 +108,7 @@ is called when compiling the template.
 sub to_func {
 	my ($self, $script, $name) = @_;
 
-	$script = ($script =~ /\A.*\Z/s) && $& if $Tenjin::BYPASS_TAINT;
+	$script = ($script =~ /\A(.*)\Z/s) && $1 if $Tenjin::BYPASS_TAINT;
 	my $s = $name ? "# line 1 \"$name\"\n" : '';  # line directive
 	$s .= "sub { my (\$_context) = \@_; $script }";
 	
@@ -212,37 +208,8 @@ information.
 
 L<Tenjin>, L<Tenjin::Util>, L<Tenjin::Template>.
 
-=head1 AUTHOR
+=head1 AUTHOR, LICENSE AND COPYRIGHT
 
-The CPAN version of Tenjin was forked by Ido Perlmuter E<lt>ido at ido50.netE<gt>
-from version 0.0.2 of the original plTenjin, which is developed by Makoto Kuwata
-at L<http://www.kuwata-lab.com/tenjin/>.
+See L<Tenjin>.
 
-Development of Tenjin is done with github at L<http://github.com/ido50/Tenjin>.
-
-=head1 LICENSE AND COPYRIGHT
-
-Tenjin is licensed under the MIT license.
-
-	Copyright (c) 2007-2010 the aforementioned authors.
-
-	Permission is hereby granted, free of charge, to any person obtaining
-	a copy of this software and associated documentation files (the
-	"Software"), to deal in the Software without restriction, including
-	without limitation the rights to use, copy, modify, merge, publish,
-	distribute, sublicense, and/or sell copies of the Software, and to
-	permit persons to whom the Software is furnished to do so, subject to
-	the following conditions:
-
-	The above copyright notice and this permission notice shall be
-	included in all copies or substantial portions of the Software.
-
-	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-	EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-	MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-	NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
-	LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-	OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-	WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-=cut
\ No newline at end of file
+=cut
