@@ -5,17 +5,13 @@ use warnings;
 use Fcntl qw/:flock/;
 use Carp;
 
-our $VERSION = "0.070001";
+our $VERSION = "1.000000";
 $VERSION = eval $VERSION;
 
 =head1 NAME
 
 Tenjin::Template - A Tenjin template object, either built from a file or from memory.
 
-=head1 VERSION
-
-version 0.070001
-
 =head1 SYNOPSIS
 
 	# mostly used internally, but you can manipulate
@@ -353,12 +349,12 @@ sub parse_expr {
 		my $start = $-[0];
 		my $text = substr($input, $pos, $start - $pos);
 		my ($expr, $flag_escape, $delete_newline) = $self->get_expr_and_escapeflag($1, $2, $3);
-		$pos = $start + length($&);
+		$pos = $+[0];
 		$self->add_text($bufref, $text) if $text;
 		$self->add_expr($bufref, $expr, $flag_escape) if $expr;
 		if ($delete_newline) {
 			my $end = $+[0];
-			if (substr($input, $end + 1, 1) eq "\n") {
+			if (substr($input, $end, 1) eq "\n") {
 				$bufref->[0] .= "\n";
 				$pos++;
 			}
@@ -397,7 +393,7 @@ sub add_text {
 	my ($self, $bufref, $text) = @_;
 
 	return unless $text;
-	$text =~ s/[`\\]/\\$&/g;
+	$text =~ s/([`\\])/\\$1/g;
 	my $is_start = $bufref->[0] =~ / \$_buf \.= \Z/;
 	$bufref->[0] .= $is_start ? "q`$text`" : " . q`$text`";
 }
@@ -533,37 +529,8 @@ sub _write_file {
 
 L<Tenjin>.
 
-=head1 AUTHOR
+=head1 AUTHOR, LICENSE AND COPYRIGHT
 
-The CPAN version of Tenjin was forked by Ido Perlmuter E<lt>ido at ido50.netE<gt>
-from version 0.0.2 of the original plTenjin, which is developed by Makoto Kuwata
-at L<http://www.kuwata-lab.com/tenjin/>.
+See L<Tenjin>.
 
-Development of Tenjin is done with github at L<http://github.com/ido50/Tenjin>.
-
-=head1 LICENSE AND COPYRIGHT
-
-Tenjin is licensed under the MIT license.
-
-	Copyright (c) 2007-2010 the aforementioned authors.
-
-	Permission is hereby granted, free of charge, to any person obtaining
-	a copy of this software and associated documentation files (the
-	"Software"), to deal in the Software without restriction, including
-	without limitation the rights to use, copy, modify, merge, publish,
-	distribute, sublicense, and/or sell copies of the Software, and to
-	permit persons to whom the Software is furnished to do so, subject to
-	the following conditions:
-
-	The above copyright notice and this permission notice shall be
-	included in all copies or substantial portions of the Software.
-
-	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-	EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-	MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-	NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
-	LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-	OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-	WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-=cut
\ No newline at end of file
+=cut
