@@ -4,21 +4,17 @@ use strict;
 use warnings;
 use HTML::Entities;
 
-our $VERSION = "0.070001";
+our $VERSION = "1.000000";
 $VERSION = eval $VERSION;
 
 =head1 NAME
 
 Tenjin::Util - Utility methods for Tenjin.
 
-=head1 VERSION
-
-version 0.070001
-
 =head1 SYNOPSIS
 
 	# in your templates:
-	
+
 	# encode a URL
 	[== encode_url('http://www.google.com/search?q=tenjin&ie=utf-8&oe=utf-8&aq=t') =]
 	# returns http%3A//www.google.com/search%3Fq%3Dtenjin%26ie%3Dutf-8%26oe%3Dutf-8%26aq%3Dt
@@ -269,37 +265,8 @@ sub _decode_params {
 
 L<Tenjin>, L<Tenjin::Template>, L<Tenjin::Context>.
 
-=head1 AUTHOR
+=head1 AUTHOR, LICENSE AND COPYRIGHT
 
-The CPAN version of Tenjin was forked by Ido Perlmuter E<lt>ido at ido50.netE<gt>
-from version 0.0.2 of the original plTenjin, which is developed by Makoto Kuwata
-at L<http://www.kuwata-lab.com/tenjin/>.
+See L<Tenjin>.
 
-Development of Tenjin is done with github at L<http://github.com/ido50/Tenjin>.
-
-=head1 LICENSE AND COPYRIGHT
-
-Tenjin is licensed under the MIT license.
-
-	Copyright (c) 2007-2010 the aforementioned authors.
-
-	Permission is hereby granted, free of charge, to any person obtaining
-	a copy of this software and associated documentation files (the
-	"Software"), to deal in the Software without restriction, including
-	without limitation the rights to use, copy, modify, merge, publish,
-	distribute, sublicense, and/or sell copies of the Software, and to
-	permit persons to whom the Software is furnished to do so, subject to
-	the following conditions:
-
-	The above copyright notice and this permission notice shall be
-	included in all copies or substantial portions of the Software.
-
-	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-	EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-	MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-	NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
-	LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-	OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-	WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-=cut
\ No newline at end of file
+=cut
